@@ -1,6 +1,7 @@
 """Provides the HTTP request handling interface."""
 import requests
-from .const import __version__, TIMEOUT
+
+from .const import TIMEOUT, __version__
 from .exceptions import InvalidInvocation, RequestException
 
 
@@ -22,23 +23,23 @@ class Requestor(object):
     ):
         """Create an instance of the Requestor class.
 
-        :param user_agent: The user-agent for your application. Please follow
-            reddit's user-agent guidlines:
-            https://github.com/reddit/reddit/wiki/API#rules
-        :param oauth_url: (Optional) The URL used to make OAuth requests to the
-            reddit site. (Default: https://oauth.reddit.com)
-        :param reddit_url: (Optional) The URL used when obtaining access
-            tokens. (Default: https://www.reddit.com)
-        :param session: (Optional) A session to handle requests, compatible
-            with requests.Session(). (Default: None)
+        :param user_agent: The user-agent for your application. Please follow reddit's
+            user-agent guidelines: https://github.com/reddit/reddit/wiki/API#rules
+        :param oauth_url: (Optional) The URL used to make OAuth requests to the reddit
+            site. (Default: https://oauth.reddit.com)
+        :param reddit_url: (Optional) The URL used when obtaining access tokens.
+            (Default: https://www.reddit.com)
+        :param session: (Optional) A session to handle requests, compatible with
+            requests.Session(). (Default: None)
+
         """
         if user_agent is None or len(user_agent) < 7:
             raise InvalidInvocation("user_agent is not descriptive")
 
         self._http = session or requests.Session()
-        self._http.headers["User-Agent"] = "{} prawcore/{}".format(
-            user_agent, __version__
-        )
+        self._http.headers[
+            "User-Agent"
+        ] = f"{user_agent} prawcore/{__version__}"
 
         self.oauth_url = oauth_url
         self.reddit_url = reddit_url
